Skip to main contentCrate voidconf
Source - Conf
- Top-level conf struct represents a single named config source.
- ConfEntry
- Definition of a single conf option.
- EnvSource
- A
ConfSource for resolving prefixed values from environment variables.
- ConfError
- Config errors from [
voidconf].
- DEFAULT_NAME
- Name used by
Conf::default. Env vars should be prefixed VCFG_.
- AnyConfEntry
- This trait allows our
ConfEntrys to all get along in one big map. - ConfSource
- Source of config values. Can look up from the environment, read from a file, query a server, etc.
- ConfValue
- Generic config value trait. Implement this for any custom types you want to support. This
library includes several implementations for commmon types.